#!/bin/sh
#
# $Copyright: Copyright (c) 2023 Veritas Technologies LLC.
# All rights reserved.
#
# THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION AND TRADE SECRETS OF
# VERITAS TECHNOLOGIES LLC.  USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED
# WITHOUT THE PRIOR EXPRESS WRITTEN PERMISSION OF VERITAS TECHNOLOGIES LLC.
#
# The  Licensed  Software  and  Documentation  are  deemed  to be commercial
# computer  software  as  defined  in  FAR  12.212 and subject to restricted
# rights  as  defined in FAR Section 52.227-19 "Commercial Computer Software
# - Restricted  Rights"  and  DFARS 227.7202,  et seq.  "Commercial Computer
# Software  and  Commercial Computer Software Documentation," as applicable,
# and any successor regulations, whether delivered by Veritas as on premises
# or  hosted  services.  Any  use,  modification,  reproduction  release,
# performance,  display  or  disclosure  of  the  Licensed  Software  and
# Documentation by the U.S. Government shall be solely in accordance with
# the terms of this Agreement. $
#
# $RCSfile: addSVCCopyServicesType.sh,v $ $Revision: 1.1.4.5 $
#

# Possible values for $1 in %post: 1 for install, 2 for upgrade
# This script is called in case of fresh install & upgrade
install_type=$1

add_fun(){
result="`$@ 2>&1`"
if [ $? -eq 1 ]; then
        if [ `echo "$result" | grep -c "already exist"` -eq 1 -o `echo "$result" | grep -c "already in"` -eq 1 ]; then
                :
        else
                echo "$@";
        fi
fi
}

VCSHOME="${VCS_HOME:-/opt/VRTSvcs}"
ro=`${VCSHOME}/bin/haclus -value ReadOnly`
if [ $ro -eq 1 ];
then
	${VCSHOME}/bin/haconf -makerw
fi
add_fun "${VCSHOME}/bin/hatype -add SVCCopyServices"
${VCSHOME}/bin/hatype -modify SVCCopyServices SourceFile "./SVCCopyServicesTypes.cf"
${VCSHOME}/bin/hatype -modify SVCCopyServices ArgList GroupName IsConsistencyGroup SSHBinary SSHPathToIDFile SVCClusterIP SVCUserName DisconnectTakeover StopTakeover CopyTakeover

if [ $install_type -eq 1 ]; then
        # case of fresh installation to update default values. Not required in case of upgrade.
	${VCSHOME}/bin/hatype -modify SVCCopyServices OfflineMonitorInterval 0
	${VCSHOME}/bin/hatype -modify SVCCopyServices OnlineTimeout 600
	${VCSHOME}/bin/hatype -modify SVCCopyServices OpenTimeout 180
	${VCSHOME}/bin/hatype -modify SVCCopyServices RestartLimit 1
fi

${VCSHOME}/bin/hatype -modify SVCCopyServices SupportedActions update PreSwitch
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServices SSHBinary -string "/usr/bin/ssh""
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServices SSHPathToIDFile -string"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServices GroupName -string"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServices IsConsistencyGroup -integer 1"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServices SVCClusterIP -string"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServices SVCUserName -string "admin""
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServices DisconnectTakeover -integer 0"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServices StopTakeover -integer 0"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServices CopyTakeover -integer 0"
add_fun "${VCSHOME}/bin/haattr -add -temp SVCCopyServices VCSResLock -string"

add_fun "${VCSHOME}/bin/hatype -add SVCCopyServicesSnap"
${VCSHOME}/bin/hatype -modify SVCCopyServicesSnap SourceFile "./SVCCopyServicesTypes.cf"
${VCSHOME}/bin/hatype -modify SVCCopyServicesSnap ArgList TargetResName MountSnapshot UseSnapshot RequireSnapshot FCMapGroupName IsSpaceEfficientSnapshot

if [ $install_type -eq 1 ]; then
        # case of fresh installation to update default values. Not required in case of upgrade.
	${VCSHOME}/bin/hatype -modify SVCCopyServicesSnap MonitorInterval 300
	${VCSHOME}/bin/hatype -modify SVCCopyServicesSnap OpenTimeout 180
	${VCSHOME}/bin/hatype -modify SVCCopyServicesSnap NumThreads 1
	${VCSHOME}/bin/hatype -modify SVCCopyServicesSnap OfflineMonitorInterval 0
	${VCSHOME}/bin/hatype -modify SVCCopyServicesSnap OnlineTimeout 6000
	${VCSHOME}/bin/hatype -modify SVCCopyServicesSnap RestartLimit 1
fi

${VCSHOME}/bin/hatype -modify SVCCopyServicesSnap SupportedActions getfcdisks
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServicesSnap TargetResName -string"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServicesSnap MountSnapshot -integer"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServicesSnap UseSnapshot -integer"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServicesSnap RequireSnapshot -integer"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServicesSnap FCMapGroupName -string"
add_fun "${VCSHOME}/bin/haattr -add SVCCopyServicesSnap IsSpaceEfficientSnapshot -integer 0"
add_fun "${VCSHOME}/bin/haattr -add -temp SVCCopyServicesSnap Responsibility -string"
add_fun "${VCSHOME}/bin/haattr -add -temp SVCCopyServicesSnap FDFile -string"

if [ $ro -eq 1 ];
then
	${VCSHOME}/bin/haconf -dump -makero
else
	${VCSHOME}/bin/haconf -dump
fi
